@@ -2,15 +2,22 @@ import argparse
 import asyncio
 from datetime import datetime, timedelta
 
+from custom_components.mypyllant.const import COUNTRIES
+
 from myPyllant.api import MyPyllantAPI
 
 parser = argparse.ArgumentParser(description="Export data from myVaillant API   .")
 parser.add_argument("user", help="Username (email address) for the myVaillant app")
 parser.add_argument("password", help="Password for the myVaillant app")
+parser.add_argument(
+    "country",
+    help="Country your account is registered in, i.e. 'germany'",
+    choices=COUNTRIES.keys(),
+)
 
 
-async def main(user, password):
-    async with MyPyllantAPI(user, password) as api:
+async def main(user, password, country):
+    async with MyPyllantAPI(user, password, country) as api:
         async for system in api.get_systems():
             print(await api.set_holiday(system, datetime.now()))
             print(
@@ -35,4 +42,4 @@ async def main(user, password):
 
 if __name__ == "__main__":
     args = parser.parse_args()
-    asyncio.run(main(args.user, args.password))
+    asyncio.run(main(args.user, args.password, args.country))
